import {
  Component,
  ElementRef,
  OnDestroy,
  OnInit,
  ViewChild,
  ViewEncapsulation,
  AfterViewInit
} from '@angular/core';
import { MatPaginator } from '@angular/material/paginator';
import { MatSort } from '@angular/material/sort';
import { fromEvent, Subject } from 'rxjs';
import {
  debounceTime,
  distinctUntilChanged,
  map,
  switchMap
} from 'rxjs/operators';
import { takeUntil } from 'rxjs/internal/operators';

import { MatTableDataSource } from '@angular/material/table';

import { fuseAnimations } from 'src/@fuse/animations';
import { FuseUtils } from 'src/@fuse/utils';
import { BankInfoDataSource } from './list.data-source';
import { BankInfoService } from 'src/modules/sites/bank-info/service/bank-info.service';
import {
  FormGroup,
  FormBuilder,
  Validators,
  FormArray,
  FormControl
} from '@angular/forms';

import { BankInfo } from 'src/modules/sites/bank-info/model/bank-info.model';

@Component({
  selector: 'app-page-sites-bank-info-list',
  templateUrl: './list.component.html',
  styleUrls: ['./list.component.scss'],
  animations: fuseAnimations,
  encapsulation: ViewEncapsulation.None
})
export class ListComponent implements OnInit, OnDestroy, AfterViewInit {
  dataSource: BankInfoDataSource = new BankInfoDataSource(this.bankInfoService);
  // dataSource: MatTableDataSource<any>;
  displayedColumns = ['id', 'name', 'number', 'holder', 'description'];
  public bankInfoFormGroup: FormGroup;
  public bankInfoFormArray: FormArray;

  @ViewChild('filter', { static: true })
  filter: ElementRef;

  // Private
  private _unsubscribeAll: Subject<any>;

  constructor(
    private bankInfoService: BankInfoService,
    private fb: FormBuilder
  ) {
    this._unsubscribeAll = new Subject();
  }

  ngOnInit() {
    this.bankInfoFormArray = this.fb.array([]);
    this.bankInfoFormGroup = this.fb.group({
      formarray: this.bankInfoFormArray
    });
    this.dataSource.formg = this.bankInfoFormGroup;
  }

  /**
   * On destroy
   */
  ngOnDestroy(): void {
    // Unsubscribe from all subscriptions
    this._unsubscribeAll.next();
    this._unsubscribeAll.complete();
  }

  ngAfterViewInit(): void {}

  bankInfoUpdate(): void {}
}
